@@ -1,4 +1,4 @@
-# $Id: mixedsort.R 1087 2007-04-07 13:41:51Z warnes $
+# $Id: mixedsort.R 1451 2010-08-14 19:28:55Z warnes $
 
 mixedsort <- function(x) x[mixedorder(x)]
 
@@ -45,7 +45,7 @@ mixedorder <- function(x)
     ####
 
     # find and mark numbers in the form of +1.23e+45.67
-    delimited <- gsub("([+-]{0,1}[0-9\\.]+([eE][\\+\\-]{0,1}[0-9\\.]+){0,1})",
+    delimited <- gsub("([+-]{0,1}[0-9]+([eE][\\+\\-]{0,1}[0-9]+){0,1})",
                       paste(delim,"\\1",delim,sep=""), x)
 
     # separate out numbers
